==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicatorDescription = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicatorDescription extends StrategyBasedIndicatorDescription {
        constructor() {
            super();
            this.ec = 0;
            this.eb = 0;
        }
        get_type() {
            return "PercentagePriceOscillatorIndicator";
        }
        get shortPeriod() {
            return this.ec;
        }
        set shortPeriod(a) {
            this.ec = a;
            this.e("ShortPeriod");
        }
        get longPeriod() {
            return this.eb;
        }
        set longPeriod(a) {
            this.eb = a;
            this.e("LongPeriod");
        }
    }
    PercentagePriceOscillatorIndicatorDescription.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicatorDescription, 'PercentagePriceOscillatorIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return PercentagePriceOscillatorIndicatorDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicatorDescription = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicatorDescription extends StrategyBasedIndicatorDescription {
        get_type() {
            return "PercentagePriceOscillatorIndicator";
        }
        constructor() {
            super();
            this.gm = 0;
            this.gl = 0;
        }
        get shortPeriod() {
            return this.gm;
        }
        set shortPeriod(a) {
            this.gm = a;
            this.g("ShortPeriod");
        }
        get longPeriod() {
            return this.gl;
        }
        set longPeriod(a) {
            this.gl = a;
            this.g("LongPeriod");
        }
    }
    PercentagePriceOscillatorIndicatorDescription.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicatorDescription, 'PercentagePriceOscillatorIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return PercentagePriceOscillatorIndicatorDescription;
})();
